==> cscec5b-wzxt-api-3.0.1-20221222.045214-205-sources.jar: com/ejianc/business/wzxt/vo/WeighReportSaveVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 智能称重台账实体
 *
 * @author generator
 *
 */
public class WeighReportSaveVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 磅站编号
     */
    private String weighStationCode;

    /**
     * 施工部位
     */
    private String construction;
    private String pkWeighBill; // 磅单主键 P
    private String weighCode; // 磅单编号 P
    private String plateNumber; // 车牌号 P
    private Long pkSupplier; // 供应商主键
    private String forwardingUnit; // 发货单位、供应商
    private Long pkProject; // 项目主键
    private String consigneeUnit; // 收货单位、收货项目
    private String materialName; // 物料名称
    private String materialSpec; // 规格型号
    private java.math.BigDecimal grossWeight; // 毛重 P
    private java.math.BigDecimal tareWeight; // 皮重 P
    private java.math.BigDecimal netWeight; // 净重 P
    private String weightUnit; // 重量单位 P
    private String grossTime; // 毛重时间 P
    private String tareTime; // 皮重时间 P
    private String remark; // P
    private String lpId; // 轻量化平台组合ID  发货单ID&发货单子表ID P
    private String thirdWeighId; // 来源称重系统称重结果ID  P
    private Long pkDelivery; // 发货单主键
    private String pkSrcDelivery; // P
    private Long pkDeliveryB; // 发货单子表主键
    private String pkSrcDeliveryB; // P
    private Long pkPurchaseB; // 订单子表主键
    private String pkWeighApply; // 过磅申请主键 P
    private Long pkMaterial; // 物料主键
    private Long pkMatclass; // 物料类别
    private String matclassName; // 物料类别名称
    private String pkCheck; // 验收单主键 // P
    private Integer checkStatus; // 验收状态  0-未验收  1- 已验收 //P
    private String source; // 数据来源
    private String pkContractPurchase; // 合同主键
    private String contractPurchaseName; // 合同名称
    private String contractPurchaseCode; // 合同编号
    private String planBody; // 工程部位
    private java.math.BigDecimal resultNum; // 折算后数量
    private java.math.BigDecimal unitRatio; // 单位转换系数
    private java.math.BigDecimal orderNum; // 订单数量
    private java.math.BigDecimal deliveryNum; // 供方数量
    private String orderCode; // 订单编号
    private String checkCode; // 验收单号
    private String deliveryCode; // 发货编号
    private String materialCode; // 物料名称

    private String oldpk;

    public String getWeighStationCode() {
        return weighStationCode;
    }

    public void setWeighStationCode(String weighStationCode) {
        this.weighStationCode = weighStationCode;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public String getPkSrcDelivery() {
        return pkSrcDelivery;
    }

    public void setPkSrcDelivery(String pkSrcDelivery) {
        this.pkSrcDelivery = pkSrcDelivery;
    }

    public String getPkSrcDeliveryB() {
        return pkSrcDeliveryB;
    }

    public void setPkSrcDeliveryB(String pkSrcDeliveryB) {
        this.pkSrcDeliveryB = pkSrcDeliveryB;
    }

    /**
     * 磅单主键
     */
    public String getPkWeighBill() {
        return pkWeighBill;
    }

    /**
     * 磅单主键
     */
    public void setPkWeighBill(String pkWeighBill) {
        this.pkWeighBill = pkWeighBill;
    }
    /**
     * 磅单编号
     */
    public String getWeighCode() {
        return weighCode;
    }

    /**
     * 磅单编号
     */
    public void setWeighCode(String weighCode) {
        this.weighCode = weighCode;
    }
    /**
     * 车牌号
     */
    public String getPlateNumber() {
        return plateNumber;
    }

    /**
     * 车牌号
     */
    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }
    /**
     * 供应商主键
     */
    public Long getPkSupplier() {
        return pkSupplier;
    }

    /**
     * 供应商主键
     */
    public void setPkSupplier(Long pkSupplier) {
        this.pkSupplier = pkSupplier;
    }
    /**
     * 发货单位、供应商
     */
    public String getForwardingUnit() {
        return forwardingUnit;
    }

    /**
     * 发货单位、供应商
     */
    public void setForwardingUnit(String forwardingUnit) {
        this.forwardingUnit = forwardingUnit;
    }
    /**
     * 项目主键
     */
    public Long getPkProject() {
        return pkProject;
    }

    /**
     * 项目主键
     */
    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    /**
     * 收货单位、收货项目
     */
    public String getConsigneeUnit() {
        return consigneeUnit;
    }

    /**
     * 收货单位、收货项目
     */
    public void setConsigneeUnit(String consigneeUnit) {
        this.consigneeUnit = consigneeUnit;
    }
    /**
     * 物料名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物料名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 规格型号
     */
    public String getMaterialSpec() {
        return materialSpec;
    }

    /**
     * 规格型号
     */
    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    /**
     * 毛重
     */
    public java.math.BigDecimal getGrossWeight() {
        return grossWeight;
    }

    /**
     * 毛重
     */
    public void setGrossWeight(java.math.BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }
    /**
     * 皮重
     */
    public java.math.BigDecimal getTareWeight() {
        return tareWeight;
    }

    /**
     * 皮重
     */
    public void setTareWeight(java.math.BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    /**
     * 净重
     */
    public java.math.BigDecimal getNetWeight() {
        return netWeight;
    }

    /**
     * 净重
     */
    public void setNetWeight(java.math.BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    /**
     * 重量单位
     */
    public String getWeightUnit() {
        return weightUnit;
    }

    /**
     * 重量单位
     */
    public void setWeightUnit(String weightUnit) {
        this.weightUnit = weightUnit;
    }
    /**
     * 毛重时间
     */
    public String getGrossTime() {
        return grossTime;
    }

    /**
     * 毛重时间
     */
    public void setGrossTime(String grossTime) {
        this.grossTime = grossTime;
    }
    /**
     * 皮重时间
     */
    public String getTareTime() {
        return tareTime;
    }

    /**
     * 皮重时间
     */
    public void setTareTime(String tareTime) {
        this.tareTime = tareTime;
    }
    /**
     *
     */
    public String getRemark() {
        return remark;
    }

    /**
     *
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    public String getLpId() {
        return lpId;
    }

    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    public void setLpId(String lpId) {
        this.lpId = lpId;
    }
    /**
     * 来源称重系统称重结果ID
     */
    public String getThirdWeighId() {
        return thirdWeighId;
    }

    /**
     * 来源称重系统称重结果ID
     */
    public void setThirdWeighId(String thirdWeighId) {
        this.thirdWeighId = thirdWeighId;
    }
    /**
     * 发货单主键
     */
    public Long getPkDelivery() {
        return pkDelivery;
    }

    /**
     * 发货单主键
     */
    public void setPkDelivery(Long pkDelivery) {
        this.pkDelivery = pkDelivery;
    }
    /**
     * 发货单子表主键
     */
    public Long getPkDeliveryB() {
        return pkDeliveryB;
    }

    /**
     * 发货单子表主键
     */
    public void setPkDeliveryB(Long pkDeliveryB) {
        this.pkDeliveryB = pkDeliveryB;
    }
    /**
     * 订单子表主键
     */
    public Long getPkPurchaseB() {
        return pkPurchaseB;
    }

    /**
     * 订单子表主键
     */
    public void setPkPurchaseB(Long pkPurchaseB) {
        this.pkPurchaseB = pkPurchaseB;
    }
    /**
     * 过磅申请主键
     */
    public String getPkWeighApply() {
        return pkWeighApply;
    }

    /**
     * 过磅申请主键
     */
    public void setPkWeighApply(String pkWeighApply) {
        this.pkWeighApply = pkWeighApply;
    }
    /**
     * 物料主键
     */
    public Long getPkMaterial() {
        return pkMaterial;
    }

    /**
     * 物料主键
     */
    public void setPkMaterial(Long pkMaterial) {
        this.pkMaterial = pkMaterial;
    }
    /**
     * 物料类别
     */
    public Long getPkMatclass() {
        return pkMatclass;
    }

    /**
     * 物料类别
     */
    public void setPkMatclass(Long pkMatclass) {
        this.pkMatclass = pkMatclass;
    }
    /**
     * 物料类别名称
     */
    public String getMatclassName() {
        return matclassName;
    }

    /**
     * 物料类别名称
     */
    public void setMatclassName(String matclassName) {
        this.matclassName = matclassName;
    }
    /**
     * 验收单主键
     */
    public String getPkCheck() {
        return pkCheck;
    }

    /**
     * 验收单主键
     */
    public void setPkCheck(String pkCheck) {
        this.pkCheck = pkCheck;
    }
    /**
     * 验收状态  0-未验收  1- 已验收
     */
    public Integer getCheckStatus() {
        return checkStatus;
    }

    /**
     * 验收状态  0-未验收  1- 已验收
     */
    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }
    /**
     * 数据来源
     */
    public String getSource() {
        return source;
    }

    /**
     * 数据来源
     */
    public void setSource(String source) {
        this.source = source;
    }
    /**
     * 合同主键
     */
    public String getPkContractPurchase() {
        return pkContractPurchase;
    }

    /**
     * 合同主键
     */
    public void setPkContractPurchase(String pkContractPurchase) {
        this.pkContractPurchase = pkContractPurchase;
    }
    /**
     * 合同名称
     */
    public String getContractPurchaseName() {
        return contractPurchaseName;
    }

    /**
     * 合同名称
     */
    public void setContractPurchaseName(String contractPurchaseName) {
        this.contractPurchaseName = contractPurchaseName;
    }
    /**
     * 合同编号
     */
    public String getContractPurchaseCode() {
        return contractPurchaseCode;
    }

    /**
     * 合同编号
     */
    public void setContractPurchaseCode(String contractPurchaseCode) {
        this.contractPurchaseCode = contractPurchaseCode;
    }
    /**
     * 工程部位
     */
    public String getPlanBody() {
        return planBody;
    }

    /**
     * 工程部位
     */
    public void setPlanBody(String planBody) {
        this.planBody = planBody;
    }
    /**
     * 折算后数量
     */
    public java.math.BigDecimal getResultNum() {
        return resultNum;
    }

    /**
     * 折算后数量
     */
    public void setResultNum(java.math.BigDecimal resultNum) {
        this.resultNum = resultNum;
    }
    /**
     * 单位转换系数
     */
    public java.math.BigDecimal getUnitRatio() {
        return unitRatio;
    }

    /**
     * 单位转换系数
     */
    public void setUnitRatio(java.math.BigDecimal unitRatio) {
        this.unitRatio = unitRatio;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNum() {
        return orderNum;
    }

    /**
     * 订单数量
     */
    public void setOrderNum(java.math.BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    /**
     * 供方数量
     */
    public java.math.BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    /**
     * 供方数量
     */
    public void setDeliveryNum(java.math.BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }
    /**
     * 订单编号
     */
    public String getOrderCode() {
        return orderCode;
    }

    /**
     * 订单编号
     */
    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }
    /**
     * 验收单号
     */
    public String getCheckCode() {
        return checkCode;
    }

    /**
     * 验收单号
     */
    public void setCheckCode(String checkCode) {
        this.checkCode = checkCode;
    }
    /**
     * 发货编号
     */
    public String getDeliveryCode() {
        return deliveryCode;
    }

    /**
     * 发货编号
     */
    public void setDeliveryCode(String deliveryCode) {
        this.deliveryCode = deliveryCode;
    }
    /**
     * 物料名称
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料名称
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getOldpk() {
        return oldpk;
    }

    public void setOldpk(String oldpk) {
        this.oldpk = oldpk;
    }
}

==> cscec5b-wzxt-api-3.0.1-20231114.075446-349-sources.jar: com/ejianc/business/wzxt/vo/WeighReportSaveVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 智能称重台账实体
 *
 * @author generator
 *
 */
public class WeighReportSaveVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 磅站编号
     */
    private String weighStationCode;

    /**
     * 施工部位
     */
    private String construction;
    private String pkWeighBill; // 磅单主键 P
    private String weighCode; // 磅单编号 P
    private String plateNumber; // 车牌号 P
    private Long pkSupplier; // 供应商主键
    private String forwardingUnit; // 发货单位、供应商
    private Long pkProject; // 项目主键
    private String consigneeUnit; // 收货单位、收货项目
    private String materialName; // 物料名称
    private String materialSpec; // 规格型号
    private java.math.BigDecimal grossWeight; // 毛重 P
    private java.math.BigDecimal tareWeight; // 皮重 P
    private java.math.BigDecimal netWeight; // 净重 P
    private String weightUnit; // 重量单位 P
    private String grossTime; // 毛重时间 P
    private String tareTime; // 皮重时间 P
    private String remark; // P
    private String lpId; // 轻量化平台组合ID  发货单ID&发货单子表ID P
    private String thirdWeighId; // 来源称重系统称重结果ID  P
    private Long pkDelivery; // 发货单主键
    private String pkSrcDelivery; // P
    private Long pkDeliveryB; // 发货单子表主键
    private String pkSrcDeliveryB; // P
    private String pkSrcOrder; // P
    private String pkSrcOrderB; // P
    private Long pkPurchaseB; // 订单子表主键
    private String pkWeighApply; // 过磅申请主键 P
    private Long pkMaterial; // 物料主键
    private Long pkMatclass; // 物料类别
    private String matclassName; // 物料类别名称
    private String pkCheck; // 验收单主键 // P
    private Integer checkStatus; // 验收状态  0-未验收  1- 已验收 //P
    private String source; // 数据来源
    private String pkContractPurchase; // 合同主键
    private String contractPurchaseName; // 合同名称
    private String contractPurchaseCode; // 合同编号
    private String planBody; // 工程部位
    private java.math.BigDecimal resultNum; // 折算后数量
    private java.math.BigDecimal unitRatio; // 单位转换系数
    private java.math.BigDecimal orderNum; // 订单数量
    private java.math.BigDecimal deliveryNum; // 供方数量
    private String orderCode; // 订单编号
    private String checkCode; // 验收单号
    private String deliveryCode; // 发货编号
    private String materialCode; // 物料名称

    private String oldpk;

    public String getWeighStationCode() {
        return weighStationCode;
    }

    public void setWeighStationCode(String weighStationCode) {
        this.weighStationCode = weighStationCode;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public String getPkSrcDelivery() {
        return pkSrcDelivery;
    }

    public void setPkSrcDelivery(String pkSrcDelivery) {
        this.pkSrcDelivery = pkSrcDelivery;
    }

    public String getPkSrcDeliveryB() {
        return pkSrcDeliveryB;
    }

    public void setPkSrcDeliveryB(String pkSrcDeliveryB) {
        this.pkSrcDeliveryB = pkSrcDeliveryB;
    }

    /**
     * 磅单主键
     */
    public String getPkWeighBill() {
        return pkWeighBill;
    }

    /**
     * 磅单主键
     */
    public void setPkWeighBill(String pkWeighBill) {
        this.pkWeighBill = pkWeighBill;
    }
    /**
     * 磅单编号
     */
    public String getWeighCode() {
        return weighCode;
    }

    /**
     * 磅单编号
     */
    public void setWeighCode(String weighCode) {
        this.weighCode = weighCode;
    }
    /**
     * 车牌号
     */
    public String getPlateNumber() {
        return plateNumber;
    }

    /**
     * 车牌号
     */
    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }
    /**
     * 供应商主键
     */
    public Long getPkSupplier() {
        return pkSupplier;
    }

    /**
     * 供应商主键
     */
    public void setPkSupplier(Long pkSupplier) {
        this.pkSupplier = pkSupplier;
    }
    /**
     * 发货单位、供应商
     */
    public String getForwardingUnit() {
        return forwardingUnit;
    }

    /**
     * 发货单位、供应商
     */
    public void setForwardingUnit(String forwardingUnit) {
        this.forwardingUnit = forwardingUnit;
    }
    /**
     * 项目主键
     */
    public Long getPkProject() {
        return pkProject;
    }

    /**
     * 项目主键
     */
    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    /**
     * 收货单位、收货项目
     */
    public String getConsigneeUnit() {
        return consigneeUnit;
    }

    /**
     * 收货单位、收货项目
     */
    public void setConsigneeUnit(String consigneeUnit) {
        this.consigneeUnit = consigneeUnit;
    }
    /**
     * 物料名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物料名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 规格型号
     */
    public String getMaterialSpec() {
        return materialSpec;
    }

    /**
     * 规格型号
     */
    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    /**
     * 毛重
     */
    public java.math.BigDecimal getGrossWeight() {
        return grossWeight;
    }

    /**
     * 毛重
     */
    public void setGrossWeight(java.math.BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }
    /**
     * 皮重
     */
    public java.math.BigDecimal getTareWeight() {
        return tareWeight;
    }

    /**
     * 皮重
     */
    public void setTareWeight(java.math.BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    /**
     * 净重
     */
    public java.math.BigDecimal getNetWeight() {
        return netWeight;
    }

    /**
     * 净重
     */
    public void setNetWeight(java.math.BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    /**
     * 重量单位
     */
    public String getWeightUnit() {
        return weightUnit;
    }

    /**
     * 重量单位
     */
    public void setWeightUnit(String weightUnit) {
        this.weightUnit = weightUnit;
    }
    /**
     * 毛重时间
     */
    public String getGrossTime() {
        return grossTime;
    }

    /**
     * 毛重时间
     */
    public void setGrossTime(String grossTime) {
        this.grossTime = grossTime;
    }
    /**
     * 皮重时间
     */
    public String getTareTime() {
        return tareTime;
    }

    /**
     * 皮重时间
     */
    public void setTareTime(String tareTime) {
        this.tareTime = tareTime;
    }
    /**
     *
     */
    public String getRemark() {
        return remark;
    }

    /**
     *
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    public String getLpId() {
        return lpId;
    }

    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    public void setLpId(String lpId) {
        this.lpId = lpId;
    }
    /**
     * 来源称重系统称重结果ID
     */
    public String getThirdWeighId() {
        return thirdWeighId;
    }

    /**
     * 来源称重系统称重结果ID
     */
    public void setThirdWeighId(String thirdWeighId) {
        this.thirdWeighId = thirdWeighId;
    }
    /**
     * 发货单主键
     */
    public Long getPkDelivery() {
        return pkDelivery;
    }

    /**
     * 发货单主键
     */
    public void setPkDelivery(Long pkDelivery) {
        this.pkDelivery = pkDelivery;
    }
    /**
     * 发货单子表主键
     */
    public Long getPkDeliveryB() {
        return pkDeliveryB;
    }

    /**
     * 发货单子表主键
     */
    public void setPkDeliveryB(Long pkDeliveryB) {
        this.pkDeliveryB = pkDeliveryB;
    }
    /**
     * 订单子表主键
     */
    public Long getPkPurchaseB() {
        return pkPurchaseB;
    }

    /**
     * 订单子表主键
     */
    public void setPkPurchaseB(Long pkPurchaseB) {
        this.pkPurchaseB = pkPurchaseB;
    }
    /**
     * 过磅申请主键
     */
    public String getPkWeighApply() {
        return pkWeighApply;
    }

    /**
     * 过磅申请主键
     */
    public void setPkWeighApply(String pkWeighApply) {
        this.pkWeighApply = pkWeighApply;
    }
    /**
     * 物料主键
     */
    public Long getPkMaterial() {
        return pkMaterial;
    }

    /**
     * 物料主键
     */
    public void setPkMaterial(Long pkMaterial) {
        this.pkMaterial = pkMaterial;
    }
    /**
     * 物料类别
     */
    public Long getPkMatclass() {
        return pkMatclass;
    }

    /**
     * 物料类别
     */
    public void setPkMatclass(Long pkMatclass) {
        this.pkMatclass = pkMatclass;
    }
    /**
     * 物料类别名称
     */
    public String getMatclassName() {
        return matclassName;
    }

    /**
     * 物料类别名称
     */
    public void setMatclassName(String matclassName) {
        this.matclassName = matclassName;
    }
    /**
     * 验收单主键
     */
    public String getPkCheck() {
        return pkCheck;
    }

    /**
     * 验收单主键
     */
    public void setPkCheck(String pkCheck) {
        this.pkCheck = pkCheck;
    }
    /**
     * 验收状态  0-未验收  1- 已验收
     */
    public Integer getCheckStatus() {
        return checkStatus;
    }

    /**
     * 验收状态  0-未验收  1- 已验收
     */
    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }
    /**
     * 数据来源
     */
    public String getSource() {
        return source;
    }

    /**
     * 数据来源
     */
    public void setSource(String source) {
        this.source = source;
    }
    /**
     * 合同主键
     */
    public String getPkContractPurchase() {
        return pkContractPurchase;
    }

    /**
     * 合同主键
     */
    public void setPkContractPurchase(String pkContractPurchase) {
        this.pkContractPurchase = pkContractPurchase;
    }
    /**
     * 合同名称
     */
    public String getContractPurchaseName() {
        return contractPurchaseName;
    }

    /**
     * 合同名称
     */
    public void setContractPurchaseName(String contractPurchaseName) {
        this.contractPurchaseName = contractPurchaseName;
    }
    /**
     * 合同编号
     */
    public String getContractPurchaseCode() {
        return contractPurchaseCode;
    }

    /**
     * 合同编号
     */
    public void setContractPurchaseCode(String contractPurchaseCode) {
        this.contractPurchaseCode = contractPurchaseCode;
    }
    /**
     * 工程部位
     */
    public String getPlanBody() {
        return planBody;
    }

    /**
     * 工程部位
     */
    public void setPlanBody(String planBody) {
        this.planBody = planBody;
    }
    /**
     * 折算后数量
     */
    public java.math.BigDecimal getResultNum() {
        return resultNum;
    }

    /**
     * 折算后数量
     */
    public void setResultNum(java.math.BigDecimal resultNum) {
        this.resultNum = resultNum;
    }
    /**
     * 单位转换系数
     */
    public java.math.BigDecimal getUnitRatio() {
        return unitRatio;
    }

    /**
     * 单位转换系数
     */
    public void setUnitRatio(java.math.BigDecimal unitRatio) {
        this.unitRatio = unitRatio;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNum() {
        return orderNum;
    }

    /**
     * 订单数量
     */
    public void setOrderNum(java.math.BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    /**
     * 供方数量
     */
    public java.math.BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    /**
     * 供方数量
     */
    public void setDeliveryNum(java.math.BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }
    /**
     * 订单编号
     */
    public String getOrderCode() {
        return orderCode;
    }

    /**
     * 订单编号
     */
    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }
    /**
     * 验收单号
     */
    public String getCheckCode() {
        return checkCode;
    }

    /**
     * 验收单号
     */
    public void setCheckCode(String checkCode) {
        this.checkCode = checkCode;
    }
    /**
     * 发货编号
     */
    public String getDeliveryCode() {
        return deliveryCode;
    }

    /**
     * 发货编号
     */
    public void setDeliveryCode(String deliveryCode) {
        this.deliveryCode = deliveryCode;
    }
    /**
     * 物料名称
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料名称
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getPkSrcOrder() {
        return pkSrcOrder;
    }

    public void setPkSrcOrder(String pkSrcOrder) {
        this.pkSrcOrder = pkSrcOrder;
    }

    public String getPkSrcOrderB() {
        return pkSrcOrderB;
    }

    public void setPkSrcOrderB(String pkSrcOrderB) {
        this.pkSrcOrderB = pkSrcOrderB;
    }

    public String getOldpk() {
        return oldpk;
    }

    public void setOldpk(String oldpk) {
        this.oldpk = oldpk;
    }
}
